@@ -26,8 +26,7 @@ from opensearchpy import OpenSearch, RequestsHttpConnection
 if TYPE_CHECKING:
     from opensearchpy import Connection as OpenSearchConnectionClass
 
-from airflow.exceptions import AirflowException
-from airflow.providers.opensearch.version_compat import BaseHook
+from airflow.providers.common.compat.sdk import AirflowException, BaseHook
 from airflow.utils.strings import to_boolean
 
 
