@@ -33,8 +33,8 @@ from opensearchpy import OpenSearch
 from opensearchpy.exceptions import NotFoundError
 
 from airflow.configuration import conf
-from airflow.exceptions import AirflowException
 from airflow.models import DagRun
+from airflow.providers.common.compat.sdk import AirflowException
 from airflow.providers.opensearch.log.os_json_formatter import OpensearchJSONFormatter
 from airflow.providers.opensearch.log.os_response import Hit, OpensearchResponse
 from airflow.providers.opensearch.version_compat import AIRFLOW_V_3_0_PLUS
